@@ -1,7 +1,8 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-gtk-0.12.5.7/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: gtk
-version: 0.12.4
-id: gtk-0.12.4-d8f2898332e5504a6337263e25379f59
+version: 0.12.5.7
+id: gtk-0.12.5.7-e67035cea6a2d971d3cb62d203d12660
 
 license: LGPL-2.1
 copyright: (c) 2001-2010 The Gtk2Hs Team
@@ -59,7 +60,7 @@ exposed-modules: Graphics.UI.Gtk Graphics.UI.GtkInternals
                  Graphics.UI.Gtk.General.Drag Graphics.UI.Gtk.General.General
                  Graphics.UI.Gtk.General.IconFactory
                  Graphics.UI.Gtk.General.IconTheme Graphics.UI.Gtk.General.RcStyle
-                 Graphics.UI.Gtk.General.Selection
+                 Graphics.UI.Gtk.General.Selection Graphics.UI.Gtk.General.Settings
                  Graphics.UI.Gtk.General.StockItems Graphics.UI.Gtk.General.Style
                  Graphics.UI.Gtk.Layout.Alignment Graphics.UI.Gtk.Layout.AspectFrame
                  Graphics.UI.Gtk.Layout.Expander Graphics.UI.Gtk.Layout.Fixed
@@ -173,10 +174,10 @@ hidden-modules: Graphics.UI.Gtk.Gdk.Enums
                 Graphics.UI.Gtk.General.DNDTypes Graphics.UI.Gtk.General.Threading
                 Graphics.UI.Gtk.Types Graphics.UI.Gtk.Signals
 trusted: False
-import-dirs: /usr/local/lib/ghc/gtk-0.12.4
-library-dirs: /usr/local/lib/ghc/gtk-0.12.4 /usr/local/lib
+import-dirs: /usr/local/lib/ghc/gtk-0.12.5.7
+library-dirs: /usr/local/lib/ghc/gtk-0.12.5.7 /usr/local/lib
               /usr/X11R6/lib
-hs-libraries: HSgtk-0.12.4
+hs-libraries: HSgtk-0.12.5.7
 extra-libraries: gthread-2.0 gtk-x11-2.0 gdk-x11-2.0 pangocairo-1.0
                  Xrender Xinerama Xi Xrandr Xcursor Xcomposite Xdamage Xfixes X11
                  Xext atk-1.0 cairo gdk_pixbuf-2.0 gio-2.0 pangoft2-1.0 pango-1.0 m
@@ -191,20 +192,20 @@ include-dirs: /usr/local/include/gtk-2.0
               /usr/local/include/glib-2.0 /usr/local/lib/glib-2.0/include
               /usr/local/include /usr/X11R6/include/freetype2 /usr/include
 includes:
-depends: array-0.4.0.1-3b78425c10ff2dad7acf7e8c8ae014c3
-         base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
-         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
-         cairo-0.12.3.1-d4207e23507b2ab76569f41a8d5db686
-         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
-         gio-0.12.4-a17738b9fa63112ce05f51d740ccb9ab
-         glib-0.12.4-e3c24025d434894ff47dcfccf269abe4
-         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
-         pango-0.12.3-21ea262e79746dde1ee277978b354f0c
+depends: array-0.5.0.0-470385a50d2b78598af85cfe9d988e1b
+         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         bytestring-0.10.4.0-84f2b632cefc94e5dfeafb660607fcbd
+         cairo-0.12.5.3-60c469fc414ed18be9b2430b7c406ed1
+         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
+         gio-0.12.5.3-d5f59e6ced5a8c3a09541d2e6c7df575
+         glib-0.12.5.4-d17f895d256b06ee8202922370af528b
+         mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
+         pango-0.12.5.3-a2e1dda058b4df125806a098dab947ce
 hugs-options:
 cc-options:
 ld-options: -pthread "-Wl,-rpath-link,/usr/X11R6/lib"
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-gtk-0.12.4/html/gtk.haddock
-haddock-html: /usr/local/share/doc/hs-gtk-0.12.4/html
+haddock-interfaces: /usr/local/share/doc/hs-gtk-0.12.5.7/html/gtk.haddock
+haddock-html: /usr/local/share/doc/hs-gtk-0.12.5.7/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
